package com.ruoyi.powerdistribution.mapper;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmConstructor;
import org.apache.ibatis.annotations.Param;

/**
 * 配网工程队伍施工人员信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-01-20
 */
public interface PdmConstructorMapper 
{
    /**
     * 查询配网工程队伍施工人员信息
     * 
     * @param id 配网工程队伍施工人员信息主键
     * @return 配网工程队伍施工人员信息
     */
    public PdmConstructor selectPdmConstructorById(Long id);

    /**
     * 查询配网工程队伍施工人员信息列表
     * 
     * @param pdmConstructor 配网工程队伍施工人员信息
     * @return 配网工程队伍施工人员信息集合
     */
    public List<PdmConstructor> selectPdmConstructorList(PdmConstructor pdmConstructor);

    /**
     * 新增配网工程队伍施工人员信息
     * 
     * @param pdmConstructor 配网工程队伍施工人员信息
     * @return 结果
     */
    public int insertPdmConstructor(PdmConstructor pdmConstructor);

    /**
     * 修改配网工程队伍施工人员信息
     * 
     * @param pdmConstructor 配网工程队伍施工人员信息
     * @return 结果
     */
    public int updatePdmConstructor(PdmConstructor pdmConstructor);

    /**
     * 删除配网工程队伍施工人员信息
     * 
     * @param id 配网工程队伍施工人员信息主键
     * @return 结果
     */
    public int deletePdmConstructorById(Long id);

    /**
     * 批量删除配网工程队伍施工人员信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePdmConstructorByIds(Long[] ids);

    /**
     *
     * @param teamId
     * @return
     */
    public int deletePdmConstructorByTeamId(@Param("teamId")Long teamId);

    public  int deletePdmConstructorByTeamIds(Long[] ids);

    public List<PdmConstructor> selectPdmConstructorByTeamNo(@Param("teamNo")String teamNo);
}
